import { SvelteComponentTyped } from "svelte";
import type { OnCreateParticle, OnUpdateParticle, ParticleStyle, Position } from './utils/types';
declare const __propDef: {
    props: {
        /**
             * The origin position of the confetti burst.
             * @required
             * @example
             * ```
             * <ConfettiBurst origin={[50, 50]} />
             * ```
             */ origin: Position;
        /**
             * A list of render styles to use for the confetti. Each confetti will be assigned a random value from the list.
             * The values can either be valid HTML colors or an HTMLImageElement.
             * @default ['hotpink','gold','dodgerblue','tomato','rebeccapurple','lightgreen','turquoise']
             * @example
             * ```
             * <ConfettiBurst colors={['red', '#ff0000', 'hsl(250, 54%, 85%)']} />
             * ```
             */ styles?: ParticleStyle[] | undefined;
        /**
             * The number of particles to create.
             * @default 50
             * @example
             * ```
             * <ConfettiBurst particleCount={100} />
             * ```
             */ particleCount?: number | undefined;
        /**
             * By default, each particle is created with some random variation. The initial values of each particle can be overriden using the onCreate callback.
             * @default undefined
             * @example
             * ```
             * <ConfettiBurst
             *   onCreate={(particle) => {
             *     particle.style = 'blue';
             *     particle.x = window.innerWidth / 2;
             *     return particle;
             * 	 }}
             * />
             * ```
             */ onCreate?: OnCreateParticle | undefined;
        /**
             * The onUpdate callback can be used to modify the particle on each frame.
             * @default undefined
             * @example
             * ```
             * <ConfettiBurst
             *   onUpdate={(particle, deltaTime) => {
             *     if (particle.angle < 0 && particle.da < 0) {
             *       particle.da *= -1;
             * 		 }
             * 	 }}
             * />
             * ```
             */ onUpdate?: OnUpdateParticle | undefined;
    };
    events: {
        completed: CustomEvent<any>;
    } & {
        [evt: string]: CustomEvent<any>;
    };
    slots: {};
};
export declare type ConfettiBurstProps = typeof __propDef.props;
export declare type ConfettiBurstEvents = typeof __propDef.events;
export declare type ConfettiBurstSlots = typeof __propDef.slots;
export default class ConfettiBurst extends SvelteComponentTyped<ConfettiBurstProps, ConfettiBurstEvents, ConfettiBurstSlots> {
}
export {};
