import { SvelteComponentTyped } from "svelte";
import type { OnCreateParticle, OnUpdateParticle, ParticleStyle } from './utils/types';
declare const __propDef: {
    props: {
        /**
             * A list of render styles to use for the confetti. Each confetti will be assigned a random value from the list.
             * The values can either be valid HTML colors or an HTMLImageElement.
             * @default ['hotpink','gold','dodgerblue','tomato','rebeccapurple','lightgreen','turquoise']
             * @example
             * ```
             * <Confetti colors={['red', '#ff0000', 'hsl(250, 54%, 85%)']} />
             * ```
             */ styles?: ParticleStyle[] | undefined;
        /**
             * The number of particles to create.
             * @default 50
             * @example
             * ```
             * <Confetti particleCount={100} />
             * ```
             */ particleCount?: number | undefined;
        /**
             * By default, each particle is created with some random variation. The initial values of each particle can be overriden using the onCreate callback.
             * @default undefined
             * @example
             * ```
             * <Confetti
             *   onCreate={(particle) => {
             *     particle.style = 'blue';
             *     particle.x = window.innerWidth / 2;
             *     return particle;
             * 	 }}
             * />
             * ```
             */ onCreate?: OnCreateParticle | undefined;
        /**
             * The onUpdate callback can be used to modify the particle on each frame.
             * @default undefined
             * @example
             * ```
             * <Confetti
             *   onUpdate={(particle, deltaTime) => {
             *     if (particle.angle < 0 && particle.da < 0) {
             *       particle.da *= -1;
             * 		 }
             * 	 }}
             * />
             * ```
             */ onUpdate?: OnUpdateParticle | undefined;
    };
    events: {
        completed: CustomEvent<any>;
    } & {
        [evt: string]: CustomEvent<any>;
    };
    slots: {};
};
export declare type FallingConfettiProps = typeof __propDef.props;
export declare type FallingConfettiEvents = typeof __propDef.events;
export declare type FallingConfettiSlots = typeof __propDef.slots;
export default class FallingConfetti extends SvelteComponentTyped<FallingConfettiProps, FallingConfettiEvents, FallingConfettiSlots> {
}
export {};
